@@ -1,6 +1,5 @@
-
 /*
-    Copyright (c) 2008 Andrew Caudwell (acaudwell@gmail.com)
+    Copyright (c) 2009 Andrew Caudwell (acaudwell@gmail.com)
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -25,36 +24,34 @@
     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
     THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
- 
+
 #include "resource.h"
 
 ResourceManager::ResourceManager() {
 }
 
-ResourceManager::~ResourceManager() {
+std::string ResourceManager::getDir() {
+    return resource_dir;
+}
 
-    //free all resources
+void ResourceManager::setDir(const std::string& resource_dir) {
+    this->resource_dir = resource_dir;
+}
+
+void ResourceManager::purge() {
+    //free all resources - should be called BEFORE SDL_QUIT ...
     for(std::map<std::string, Resource*>::iterator it= resources.begin(); it!=resources.end();it++) {
         delete it->second;
     }
 
+    resources.clear();
 }
 
-Resource* ResourceManager::grab(std::string name) {
-    //debugLog("grabing %s\n", name.c_str());
-    Resource* r = resources[name];
-
-    if(r==0) {
-        //debugLog("%s not found. creating resource...\n", name.c_str());
-        r = create(name);
-        resources[name] = r;
-    }
-    r->addref();
-    return r;
+ResourceManager::~ResourceManager() {
 }
 
 void ResourceManager::release(Resource* resource) {
-    Resource* r = resources[resource->name];
+    Resource* r = resources[resource->resource_name];
 
     if(r==0) return;
 
@@ -63,8 +60,7 @@ void ResourceManager::release(Resource* resource) {
 
     if(r->refcount()<=0) {
         //debugLog("no refs to %s, deleting\n", name.c_str());
-        resources.erase(r->name); //sufficient?
+        resources.erase(r->resource_name); //sufficient?
         delete r;
     }
 }
-
