@@ -27,7 +27,7 @@
 
 #include "seeklog.h"
 
-long gSeekLogMaxBufferSize = 104857600;
+long long gSeekLogMaxBufferSize = 104857600;
 
 //StreamLog
 
@@ -42,7 +42,7 @@ StreamLog::StreamLog() {
     int ret = fcntl(STDIN_FILENO, F_GETFL, 0);
 
     if (fcntl (STDIN_FILENO, F_SETFL, ret | O_NONBLOCK) < 0) {
-        debugLog("fcntl(stdin) failed\n");
+        debugLog("fcntl(stdin) failed");
         fcntl_fail = true;
     }
 #endif
@@ -107,6 +107,7 @@ bool SeekLog::readFully() {
     if(stream!=0) delete stream;
 
     std::ifstream* file = new std::ifstream(logfile.c_str(), std::ios::in | std::ios::binary | std::ios::ate);
+
     file_size = file->tellg();
 
     if(!file->is_open()) return false;
@@ -119,12 +120,14 @@ bool SeekLog::readFully() {
         return true;
     }
 
+
     //buffer entire file into memory
     char* filebuffer = new char[file_size+1];
 
     if(!file->read(filebuffer, file_size)) {
         file->close();
         delete file;
+        delete [] filebuffer;
         return false;
     }
     filebuffer[file_size] = '\0';
@@ -159,12 +162,12 @@ void SeekLog::seekTo(float percent) {
 
     if(isFinished()) stream->clear();
 
-    std::streampos mem_pointer = (std::streampos) (percent * file_size);
+    std::streampos mem_offset = (std::streampos) (percent * file_size);
 
-    setPointer(mem_pointer);
+    setPointer(mem_offset);
     
     //throw away end of line
-    if(mem_pointer!=0) {
+    if(mem_offset != (std::streampos)0) {
         std::string eol;
         getNextLine(eol);
     }
@@ -214,7 +217,7 @@ bool SeekLog::isFinished() {
     bool finished = false;
 
     if(stream->fail() || stream->eof()) {
-        debugLog("stream is finished\n");
+        //debugLog("stream is finished");
         finished=true;
     }
 
