@@ -1,5 +1,7 @@
 #include "custom.h"
 
+#include "core/regex.h"
+
 //timestamp
 //hostname
 //path
@@ -32,10 +34,10 @@ bool CustomAccessLog::parseLine(std::string& line, LogEntry& entry) {
     //optional fields
 
     //success 1 or 0
-    if(matches.size()>5) {
+    if(matches.size() > 5) {
         std::string success = matches[5];
 
-        if(success.size()==0 || success.size()==1 && success[0] == ' ') {
+        if(success.empty() || (success.size()==1 && success[0] == ' ')) {
             entry.setSuccess();
         } else {
             entry.successful = atoi(success.c_str())==1 ? true : false;
@@ -50,7 +52,7 @@ bool CustomAccessLog::parseLine(std::string& line, LogEntry& entry) {
         int r, g, b;
         if(colour.size()>0 &&
            sscanf(colour.c_str(), "%02x%02x%02x", &r, &g, &b) == 3) {
-            entry.response_colour = vec3f( r, g, b );
+            entry.response_colour = vec3( r, g, b );
             entry.response_colour /= 255.0f;
         } else {
             entry.setResponseColour();
