@@ -18,22 +18,14 @@
 #ifndef LOGENTRY_H
 #define LOGENTRY_H
 
-#include <string>
-#include <string.h>
-
-#include <vector>
-#include <time.h>
-
-#include "core/sdlapp.h"
 #include "core/vectors.h"
-#include "core/regex.h"
 
-extern bool  gMask;
+#include <string>
 
 class LogEntry {
 
 private:
-    std::string maskHostname(std::string hostname);
+    std::string maskHostname(const std::string& hostname);
 public:
     LogEntry();
     bool validate();
@@ -41,7 +33,7 @@ public:
     void setSuccess();
     void setResponseColour();
 
-    long timestamp;
+    time_t timestamp;
 
     std::string hostname;
     std::string vhost;
@@ -56,7 +48,7 @@ public:
     std::string referrer;
     std::string user_agent;
 
-    vec3f response_colour;
+    vec3 response_colour;
 
     bool successful;
 };
@@ -66,7 +58,7 @@ class AccessLog {
 public:
     AccessLog();
     virtual ~AccessLog() {};
-    virtual bool parseLine(std::string& line, LogEntry& entry) {};
+    virtual bool parseLine(std::string& line, LogEntry& entry) = 0;
 
 };
 
