@@ -205,6 +205,10 @@ void Logstalgia::keyPress(SDL_KeyboardEvent *e) {
             togglePause();
         }
 
+        if (e->keysym.sym == SDLK_F11) {
+            toggleWindowFrame();
+        }
+
         if (e->keysym.sym == SDLK_F12) {
             take_screenshot = true;
         }
@@ -716,6 +720,25 @@ void Logstalgia::resize(int width, int height) {
     reinit();
 }
 
+void Logstalgia::toggleWindowFrame() {
+#if SDL_VERSION_ATLEAST(2,0,0)
+    if(display.fullscreen) return;
+    if(frameExporter != 0) return;
+
+    texturemanager.unload();
+    shadermanager.unload();
+    fontmanager.unload();
+
+    display.toggleFrameless();
+
+    texturemanager.reload();
+    shadermanager.reload();
+    fontmanager.reload();
+
+    reinit();
+#endif
+}
+
 void Logstalgia::reinit() {
     initPaddles();
     initRequestBalls();
@@ -1109,7 +1132,15 @@ void Logstalgia::addGroup(const std::string& group_by, const std::string& groupt
         percent = remaining_percent;
     }
 
-    Summarizer* summarizer = new Summarizer(fontSmall, percent, settings.update_rate, groupregex, grouptitle);
+
+    Summarizer* summarizer = 0;
+
+    try {
+        summarizer = new Summarizer(fontSmall, percent, settings.update_rate, groupregex, grouptitle);
+    }
+    catch(RegexCompilationException& e) {
+        throw SDLAppException("invalid regular expression for group '%s'", grouptitle.c_str());
+    }
 
     if(glm::dot(colour, colour) > 0.01f) {
         summarizer->setColour(colour);
