@@ -1,7 +1,6 @@
 #ifndef POS_SLIDER_H
 #define POS_SLIDER_H
 
-#include "core/logger.h"
 #include "core/bounds.h"
 #include "core/fxfont.h"
 
@@ -16,21 +15,29 @@ class PositionSlider {
     float fade_time;
     float alpha;
 
-    vec3f slidercol;
+    vec3 slidercol;
 
     float capwidth;
     std::string caption;
+
+    void drawSlider(float position) const;
 public:
     PositionSlider(float percent = 0.0f);
 
-    void setColour(vec3f col);
+    void setColour(vec3 col);
 
-    void setCaption(std::string cap);
+    void setCaption(const std::string& cap);
 
     void setPercent(float percent);
 
-    bool mouseOver(vec2f pos, float* percent_ptr);
-    bool click(vec2f pos, float* percent_ptr);
+    void resize();
+
+    void show();
+
+    const Bounds2D& getBounds() const;
+
+    bool mouseOver(vec2 pos, float* percent_ptr);
+    bool click(vec2 pos, float* percent_ptr);
     void logic(float dt);
     void draw(float dt);
 };
