@@ -17,6 +17,8 @@
 
 #include "summarizer.h"
 
+#include <algorithm>
+
 /*
 
 Method:
@@ -85,15 +87,15 @@ bool SummNode::removeWord(const std::string& str, size_t offset) {
     refs--;
 
     size_t str_size = str.size() - offset;
-    
+
     if(!str_size) return false;
 
     words--;
 
     size_t no_children = children.size();
-    
+
     bool removed = false;
-    
+
     for(size_t i=0;i<no_children;i++) {
         if(children[i]->c == str[offset]) {
             removed = children[i]->removeWord(str,++offset);
@@ -112,9 +114,11 @@ bool SummNode::removeWord(const std::string& str, size_t offset) {
 }
 
 void SummNode::debug(int indent) {
-    for(int i=0;i<indent;i++)
-        debugLog(" ");
-    debugLog("node c=%c refs=%d words=%d\n", c, refs, words);
+
+    std::string indentation;
+    if(indent>0) indentation.append(indent, ' ');
+
+    debugLog("%snode c=%c refs=%d words=%d", indentation.c_str(), c, refs, words);
     indent++;
 
     for(size_t i=0;i<children.size();i++) {
@@ -124,15 +128,15 @@ void SummNode::debug(int indent) {
 }
 
 bool SummNode::addWord(const std::string& str, size_t offset) {
-    
+
     refs++;
 
     size_t str_size = str.size() - offset;
 
     if(!str_size) return false;
-    
+
     words++;
-        
+
     size_t no_children = children.size();
 
     for(size_t i=0;i<no_children;i++) {
@@ -281,8 +285,8 @@ void SummItem::updateUnit(SummUnit& unit) {
 
     this->unit = unit;
 
-    vec3f col = icol!=0 ? *icol : colourHash(unit.str);
-    this->colour = vec4f(col, 1.0f);
+    vec3 col = icol!=0 ? *icol : colourHash(unit.str);
+    this->colour = vec4(col, 1.0f);
 
     char buff[1024];
 
@@ -305,8 +309,9 @@ void SummItem::updateUnit(SummUnit& unit) {
 
 }
 
-SummItem::SummItem(SummUnit unit, vec2f pos, vec2f dest, float target_x, vec3f* icol, FXFont font, bool showcount) {
-    this->pos  = pos;
+SummItem::SummItem(SummUnit unit, float target_x, vec3* icol, FXFont font, bool showcount) {
+    this->pos  = vec2(-1.0,-1.0);
+    this->dest = vec2(-1.0,-1.0);
     this->target_x = target_x;
     this->icol = icol;
     this->font = font;
@@ -316,12 +321,15 @@ SummItem::SummItem(SummUnit unit, vec2f pos, vec2f dest, float target_x, vec3f*
 
     destroy=false;
     moving=false;
+    departing=false;
 
     setDest(dest);
 }
 
-void SummItem::setDest(vec2f dest, bool depart) {
-    if(moving && (this->dest - dest).length2()<1.0f) return;
+void SummItem::setDest(const vec2& dest) {
+    vec2 dist = this->dest - dest;
+
+    if(moving && glm::dot(dist, dist) < 1.0f) return;
 
     this->oldpos = pos;
     this->dest   = dest;
@@ -330,7 +338,15 @@ void SummItem::setDest(vec2f dest, bool depart) {
 
     destroy   = false;
     moving    = true;
-    departing = depart;
+}
+
+void SummItem::setDeparting(bool departing) {
+    this->departing = departing;
+    if(!departing) destroy = false;
+}
+
+void SummItem::setPos(const vec2& pos) {
+    this->pos = pos;
 }
 
 void SummItem::logic(float dt) {
@@ -363,18 +379,17 @@ void SummItem::logic(float dt) {
 }
 
 void SummItem::draw(float alpha) {
-    glColor4f(colour.x, colour.y, colour.z, colour.w * alpha);
+    font.setColour(vec4(colour.x, colour.y, colour.z, colour.w * alpha));
     font.draw((int)pos.x, (int)pos.y, displaystr.c_str());
 }
 
 // Summarizer
 
-Summarizer::Summarizer(FXFont font, float x, float top_gap, float bottom_gap, float refresh_delay, std::string matchstr, std::string title)
-    : matchre(matchstr)
- {
-    this->pos_x      = x;
-    this->top_gap    = top_gap;
-    this->bottom_gap = bottom_gap;
+Summarizer::Summarizer(FXFont font, int screen_percent, float refresh_delay, std::string matchstr, std::string title)
+    : matchre(matchstr) {
+    pos_x = top_gap = bottom_gap = 0.0f;
+
+    this->screen_percent = screen_percent;
     this->title      = title;
     this->font       = font;
 
@@ -386,45 +401,60 @@ Summarizer::Summarizer(FXFont font, float x, float top_gap, float bottom_gap, fl
 
     changed = false;
 
-    font_gap    = font.getHeight() + 4;
-    max_strings = (int) ((display.height-top_gap-bottom_gap)/font_gap);
     incrementf   =0;
     root = SummNode();
 
     mouseover=false;
+}
 
+int Summarizer::getScreenPercent() {
+    return screen_percent;
+}
+
+void Summarizer::setSize(int x, float top_gap, float bottom_gap) {
+    this->pos_x      = x;
+    this->top_gap    = top_gap;
+    this->bottom_gap = bottom_gap;
+
+    // TODO: set 'right' explicitly?
     right = (pos_x > (display.width/2)) ? true : false;
 
-    if(this->title.size()) {
+    font_gap = font.getMaxHeight() + 4;
+
+    max_strings = (int) ((display.height-top_gap-bottom_gap)/font_gap);
+
+    if(!title.empty()) {
         this->top_gap+= font_gap;
     }
+
+    changed = true;
+    refresh_elapsed = refresh_delay;
+    items.clear();
 }
 
 void Summarizer::mouseOut() {
     mouseover=false;
 }
 
-bool Summarizer::mouseOver(TextArea& textarea, vec2f mouse) {
+bool Summarizer::mouseOver(TextArea& textarea, vec2 mouse) {
     mouseover=false;
 
     if(right && mouse.x < pos_x) return false;
     if(mouse.y < top_gap || mouse.y > (display.height-bottom_gap)) return false;
-    if(items.size()<1) return false;
+    if(items.empty()) return false;
 
     float y = mouse.y;
 
-    std::list<SummItem>::iterator it;
-    for(it=items.begin();it!=items.end();it++) {
-        SummItem* si = &(*it);
-        if(si->departing) continue;
+    for(SummItem& item : items) {
+        if(item.departing) continue;
 
-        if(si->pos.y<=y && (si->pos.y+font.getHeight()+4) > y) {
-            if(mouse.x< si->pos.x || mouse.x > si->pos.x + si->width) continue;
+        if(item.pos.y<=y && (item.pos.y+font.getMaxHeight()+4) > y) {
+            if(mouse.x< item.pos.x || mouse.x > item.pos.x + item.width) continue;
 
             std::vector<std::string> content;
 
-            textarea.setText(si->unit.expanded);
-            textarea.setColour(si->colour.truncate());
+            textarea.setText(item.unit.expanded);
+            textarea.setColour(vec3(item.colour));
             textarea.setPos(mouse);
             mouseover=true;
             return true;
@@ -434,15 +464,15 @@ bool Summarizer::mouseOver(TextArea& textarea, vec2f mouse) {
     return false;
 }
 
-void Summarizer::setColour(vec3f col) {
-    this->item_colour = new vec3f(col);
+void Summarizer::setColour(vec3 col) {
+    this->item_colour = new vec3(col);
 }
 
 bool Summarizer::isColoured() {
     return (item_colour!=0);
 }
 
-vec3f Summarizer::getColour() {
+vec3 Summarizer::getColour() {
     return *item_colour;
 }
 
@@ -450,15 +480,33 @@ Summarizer::~Summarizer() {
     if(item_colour!=0) delete item_colour;
 }
 
-bool Summarizer::supportedString(std::string& str) {
+bool Summarizer::supportedString(const std::string& str) {
     return matchre.match(str);
 }
 
+// string sort with numbers sorted last (reasoning: text is more likely to be interesting)
+bool _unit_sorter(const SummUnit& a, const SummUnit& b) {
+
+    int ai = atoi(a.str.c_str());
+    int bi = atoi(b.str.c_str());
+    
+    // if only one of a or b is numeric, non numeric value wins
+    if((ai==0) != (bi==0)) {
+        return ai==0;
+    }
+
+    return a.str.compare(b.str) < 0;
+}
+
+bool _item_sorter(const SummItem& a, const SummItem& b) {   
+    return _unit_sorter(a.unit,b.unit);
+}
+
 void Summarizer::summarize() {
     if(!changed) return;
 
     changed = false;
-    
+
     strings.clear();
     root.summarize(strings,max_strings);
 
@@ -468,6 +516,8 @@ void Summarizer::summarize() {
         strings[i].buildSummary();
     }
 
+    std::sort(strings.begin(), strings.end(), _unit_sorter);
+    
     if(nostrs>1) {
         incrementf  = (((float)display.height-font_gap-top_gap-bottom_gap)/(nostrs-1));
     } else {
@@ -482,51 +532,73 @@ void Summarizer::recalc_display() {
     std::vector<bool> strfound;
     strfound.resize(nostrs, false);
 
-    std::list<SummItem>::iterator it;
-
+    size_t found_count = 0;
+    
     //update summItems
-    for(it=items.begin();it!=items.end();it++) {
-        SummItem* item = &(*it);
+    for(SummItem& item : items) {
 
         int match = -1;
 
         for(size_t j=0;j<nostrs;j++) {
             SummUnit summstr = strings[j];
 
-            if(summstr.str.compare(item->unit.str) == 0) {
-                item->updateUnit(summstr);
+            if(summstr.str.compare(item.unit.str) == 0) {
+                item.updateUnit(summstr);
 
                 match = (int)j;
 
                 strfound[j]= true;
-
+                found_count++;
+                
                 break;
             }
         }
 
-        if(match!= -1) {
-            float destY = calcPosY(match);
-            item->setDest(vec2f(pos_x, destY));
-        } else {
-            float destX = right ? (display.width + 100) : -100;
-            item->setDest(vec2f(destX, item->pos.y), true);
-        }
+        item.setDeparting(match == -1 ? true : false);
     }
 
     //add items for strings not found
     for(size_t i=0;i<nostrs;i++) {
         if(strfound[i]) continue;
 
-        float startX = right ? display.width + 100 : -100;
-        float destY  = getPosY(strings[i].str);
+        items.push_back(SummItem(strings[i], pos_x, item_colour, font, showcount));
+        
+        //debugLog("added item for unit %s %d", strings[i].str.c_str(), items[items.size()-1].destroy);
+    }
+    
+    // sort items alphabetically
+    std::sort(items.begin(), items.end(), _item_sorter);
 
-        items.push_back(SummItem(strings[i], vec2f(startX, destY), vec2f(pos_x, destY),pos_x, item_colour, font, showcount));
+    // set y positions
+
+    int y_index = 0;
+        
+    for(SummItem& item : items) {
+        
+        float Y = calcPosY(y_index);
+
+        if(!item.departing) y_index++;
+
+        float startX = right ? display.width + 100 : -200;
+
+        // initialize new item position
+        if(item.pos.y<0.0) {
+            item.setPos(vec2(startX, Y));
+        }
+        
+        if(item.departing) {
+            // return to start
+            item.setDest(vec2(startX, Y));
+        } else {
+            item.setDest(vec2(pos_x, Y));
+        }
+        
     }
 }
 
 void Summarizer::removeString(const std::string& str) {
     root.removeWord(str,0);
-    changed = true;    
+    changed = true;
 }
 
 float Summarizer::calcPosY(int i) const {
@@ -542,22 +614,22 @@ int Summarizer::getBestMatchIndex(const std::string& input) const {
     size_t nostrs = strings.size();
 
     for(size_t i = 0;i < nostrs; i++) {
-        
+
         size_t strn_size  = strings[i].str.size();
         size_t input_size = input.size();
 
         int size_diff = strn_size - input_size;
 
-        size_t min_size   = size_diff == 0 ? input_size : std::min ( strn_size, input_size ); 
+        size_t min_size   = size_diff == 0 ? input_size : std::min ( strn_size, input_size );
 
-        int min_common_diff = abs( strings[i].str.compare(0, min_size, input, 0, min_size) );       
+        int min_common_diff = abs( strings[i].str.compare(0, min_size, input, 0, min_size) );
 
         //found
         if(size_diff == 0 && min_common_diff == 0) {
             best = i;
             break;
         }
-        
+
         if(    best_diff == -1
             || min_common_diff < best_diff
             || (min_common_diff == best_diff //remove this?
@@ -576,13 +648,15 @@ int Summarizer::getBestMatchIndex(const std::string& input) const {
 
 const std::string& Summarizer::getBestMatchStr(const std::string& str) const {
     int pos = getBestMatchIndex(str);
-        
+
+    assert(pos !=- 1);
+
     return strings[pos].str;
 }
 
 
 float Summarizer::getMiddlePosY(const std::string& str) const {
-    return getPosY(str) + (font.getHeight()) / 2;
+    return getPosY(str) + (font.getMaxHeight()) / 2;
 }
 
 float Summarizer::getPosY(const std::string& str) const {
@@ -616,17 +690,15 @@ void Summarizer::logic(float dt) {
     }
 
     //move items
-    std::list<SummItem>::iterator it;
-    for(it = items.begin();it != items.end(); it++) {
+    for(auto it = items.begin();it != items.end();) {
         (*it).logic(dt);
 
         if((*it).destroy) {
             it = items.erase(it);
-            if(it==items.end()) {
-                break;
-            }
+        } else {
+            it++;
         }
-    }    
+    }
 }
 
 void Summarizer::draw(float dt, float alpha) {
@@ -635,13 +707,12 @@ void Summarizer::draw(float dt, float alpha) {
 	glEnable(GL_TEXTURE_2D);
 
     if(title.size()) {
-        glColor4f(1.0f, 1.0f, 1.0f, alpha);
+        font.setColour(vec4(1.0f, 1.0f, 1.0f, alpha));
         font.draw((int)pos_x, (int)(top_gap - font_gap), title.c_str());
     }
 
-    std::list<SummItem>::iterator it;
-    for(it=items.begin();it!=items.end();it++) {
-        (*it).draw(alpha);
+    for(SummItem& item : items) {
+        item.draw(alpha);
     }
 
 }
